IDialogTheme class
- Inheritance
-
- Object
- NUIEnt<
IDialogTheme> - IDialogTheme
Constructors
- IDialogTheme({String? accentColor, String? backgroundColor, String? textOnAccentColor, String? textOnBackgroundColor, String? textHighlightColor})
- IDialogTheme.empty()
Properties
- accentColor ↔ String?
-
getter/setter pair
- backgroundColor ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textHighlightColor ↔ String?
-
getter/setter pair
- textOnAccentColor ↔ String?
-
getter/setter pair
- textOnBackgroundColor ↔ String?
-
getter/setter pair
Methods
-
copyFrom(
IDialogTheme theme) → void -
fromJson(
Map< String, dynamic> json) → IDialogTheme -
inherited
-
mapper(
) → NUIEntMapper< IDialogTheme> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited